@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from typing import MutableMapping, MutableSequence
+
 import proto  # type: ignore
 
 from google.cloud.automl_v1beta1.types import geometry
@@ -61,18 +63,18 @@ class Image(proto.Message):
             Output only. HTTP URI to the thumbnail image.
     """
 
-    image_bytes = proto.Field(
+    image_bytes: bytes = proto.Field(
         proto.BYTES,
         number=1,
         oneof="data",
     )
-    input_config = proto.Field(
+    input_config: io.InputConfig = proto.Field(
         proto.MESSAGE,
         number=6,
         oneof="data",
         message=io.InputConfig,
     )
-    thumbnail_uri = proto.Field(
+    thumbnail_uri: str = proto.Field(
         proto.STRING,
         number=4,
     )
@@ -97,15 +99,15 @@ class TextSnippet(proto.Message):
             the content.
     """
 
-    content = proto.Field(
+    content: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    mime_type = proto.Field(
+    mime_type: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    content_uri = proto.Field(
+    content_uri: str = proto.Field(
         proto.STRING,
         number=4,
     )
@@ -132,16 +134,16 @@ class DocumentDimensions(proto.Message):
         CENTIMETER = 2
         POINT = 3
 
-    unit = proto.Field(
+    unit: DocumentDimensionUnit = proto.Field(
         proto.ENUM,
         number=1,
         enum=DocumentDimensionUnit,
     )
-    width = proto.Field(
+    width: float = proto.Field(
         proto.FLOAT,
         number=2,
     )
-    height = proto.Field(
+    height: float = proto.Field(
         proto.FLOAT,
         number=3,
     )
@@ -156,7 +158,7 @@ class Document(proto.Message):
             document.
         document_text (google.cloud.automl_v1beta1.types.TextSnippet):
             The plain text version of this document.
-        layout (Sequence[google.cloud.automl_v1beta1.types.Document.Layout]):
+        layout (MutableSequence[google.cloud.automl_v1beta1.types.Document.Layout]):
             Describes the layout of the document. Sorted by
             [page_number][].
         document_dimensions (google.cloud.automl_v1beta1.types.DocumentDimensions):
@@ -210,47 +212,47 @@ class Document(proto.Message):
             TABLE_ROW = 8
             TABLE_CELL = 9
 
-        text_segment = proto.Field(
+        text_segment: gca_text_segment.TextSegment = proto.Field(
             proto.MESSAGE,
             number=1,
             message=gca_text_segment.TextSegment,
         )
-        page_number = proto.Field(
+        page_number: int = proto.Field(
             proto.INT32,
             number=2,
         )
-        bounding_poly = proto.Field(
+        bounding_poly: geometry.BoundingPoly = proto.Field(
             proto.MESSAGE,
             number=3,
             message=geometry.BoundingPoly,
         )
-        text_segment_type = proto.Field(
+        text_segment_type: "Document.Layout.TextSegmentType" = proto.Field(
             proto.ENUM,
             number=4,
             enum="Document.Layout.TextSegmentType",
         )
 
-    input_config = proto.Field(
+    input_config: io.DocumentInputConfig = proto.Field(
         proto.MESSAGE,
         number=1,
         message=io.DocumentInputConfig,
     )
-    document_text = proto.Field(
+    document_text: "TextSnippet" = proto.Field(
         proto.MESSAGE,
         number=2,
         message="TextSnippet",
     )
-    layout = proto.RepeatedField(
+    layout: MutableSequence[Layout] = proto.RepeatedField(
         proto.MESSAGE,
         number=3,
         message=Layout,
     )
-    document_dimensions = proto.Field(
+    document_dimensions: "DocumentDimensions" = proto.Field(
         proto.MESSAGE,
         number=4,
         message="DocumentDimensions",
     )
-    page_count = proto.Field(
+    page_count: int = proto.Field(
         proto.INT32,
         number=5,
     )
@@ -260,7 +262,7 @@ class Row(proto.Message):
     r"""A representation of a row in a relational table.
 
     Attributes:
-        column_spec_ids (Sequence[str]):
+        column_spec_ids (MutableSequence[str]):
             The resource IDs of the column specs describing the columns
             of the row. If set must contain, but possibly in a different
             order, all input feature
@@ -269,7 +271,7 @@ class Row(proto.Message):
             of the Model this row is being passed to. Note: The below
             ``values`` field must match order of this field, if this
             field is set.
-        values (Sequence[google.protobuf.struct_pb2.Value]):
+        values (MutableSequence[google.protobuf.struct_pb2.Value]):
             Required. The values of the row cells, given in the same
             order as the column_spec_ids, or, if not set, then in the
             same order as input feature
@@ -278,11 +280,11 @@ class Row(proto.Message):
             of the Model this row is being passed to.
     """
 
-    column_spec_ids = proto.RepeatedField(
+    column_spec_ids: MutableSequence[str] = proto.RepeatedField(
         proto.STRING,
         number=2,
     )
-    values = proto.RepeatedField(
+    values: MutableSequence[struct_pb2.Value] = proto.RepeatedField(
         proto.MESSAGE,
         number=3,
         message=struct_pb2.Value,
@@ -318,25 +320,25 @@ class ExamplePayload(proto.Message):
             This field is a member of `oneof`_ ``payload``.
     """
 
-    image = proto.Field(
+    image: "Image" = proto.Field(
         proto.MESSAGE,
         number=1,
         oneof="payload",
         message="Image",
     )
-    text_snippet = proto.Field(
+    text_snippet: "TextSnippet" = proto.Field(
         proto.MESSAGE,
         number=2,
         oneof="payload",
         message="TextSnippet",
     )
-    document = proto.Field(
+    document: "Document" = proto.Field(
         proto.MESSAGE,
         number=4,
         oneof="payload",
         message="Document",
     )
-    row = proto.Field(
+    row: "Row" = proto.Field(
         proto.MESSAGE,
         number=3,
         oneof="payload",
