@@ -13,13 +13,18 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from typing import MutableMapping, MutableSequence
+
 import proto  # type: ignore
 
 from google.cloud.automl_v1beta1.types import io
 
 
 __protobuf__ = proto.module(
-    package="google.cloud.automl.v1beta1", manifest={"TableSpec",},
+    package="google.cloud.automl.v1beta1",
+    manifest={
+        "TableSpec",
+    },
 )
 
 
@@ -60,7 +65,7 @@ class TableSpec(proto.Message):
             Output only. The number of columns of the
             table. That is, the number of child
             ColumnSpec-s.
-        input_configs (Sequence[google.cloud.automl_v1beta1.types.InputConfig]):
+        input_configs (MutableSequence[google.cloud.automl_v1beta1.types.InputConfig]):
             Output only. Input configs via which data
             currently residing in the table had been
             imported.
@@ -70,15 +75,35 @@ class TableSpec(proto.Message):
             happens.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    time_column_spec_id = proto.Field(proto.STRING, number=2,)
-    row_count = proto.Field(proto.INT64, number=3,)
-    valid_row_count = proto.Field(proto.INT64, number=4,)
-    column_count = proto.Field(proto.INT64, number=7,)
-    input_configs = proto.RepeatedField(
-        proto.MESSAGE, number=5, message=io.InputConfig,
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    time_column_spec_id: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    row_count: int = proto.Field(
+        proto.INT64,
+        number=3,
+    )
+    valid_row_count: int = proto.Field(
+        proto.INT64,
+        number=4,
+    )
+    column_count: int = proto.Field(
+        proto.INT64,
+        number=7,
+    )
+    input_configs: MutableSequence[io.InputConfig] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=5,
+        message=io.InputConfig,
+    )
+    etag: str = proto.Field(
+        proto.STRING,
+        number=6,
     )
-    etag = proto.Field(proto.STRING, number=6,)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
